#pragma once
#define GIT_COMMIT_HASH    "5c9377c15f85c50648f35ca5a213754f95b93ca0"
#define GIT_BRANCH         "v0.56.1"
#define GIT_COMMIT_MESSAGE "version: bump to 0.56.1"
#define GIT_COMMIT_DATE    "Mon Jul 27 16:33:49 2026"
#define GIT_DIRTY          "clean"
#define GIT_TAG            "v0.56.1"
#define GIT_COMMITS        "7643"

#define AQUAMARINE_VERSION "0.14.0"
// clang-format off
#define AQUAMARINE_VERSION_MAJOR 0
#define AQUAMARINE_VERSION_MINOR 14
#define AQUAMARINE_VERSION_PATCH 0
// clang-format on
#define HYPRLANG_VERSION     "0.6.8"
#define HYPRUTILS_VERSION    "0.14.0"
#define HYPRCURSOR_VERSION   "0.1.13"
#define HYPRGRAPHICS_VERSION "0.5.1"
